@@ -10,21 +10,29 @@ from pagseguro.api.v2.payment import Payment as PaymentV2
 class Payment(object):
     '''
     Utilize esta classe para instanciar o objeto que fara a conexão
-    com o PagSeguro
+    com o PagSeguro.
+
+    Examples:
+
+    >>> payment = Payment(email=local_settings.PAGSEGURO_ACCOUNT_EMAIL, token=local_settings.PAGSEGURO_TOKEN, version=2)
+    >>> payment.add_item(item_id='id-do-item-1', description='Desc. do produto', amount=7, quantity=2)
+    >>> payment.add_item(item_id='id-do-item-2', description='Um outro produto', amount=24.1, quantity=2)
+    >>> payment.set_client(name='Adam Yauch', phone_area_code=11, phone_number=12341234, cpf='93537621701')
+    >>> payment.set_shipping(cost=1.2)
+    >>> payment.request()
+    >>> url = payment.payment_url
     
-    :param: email: O email do comprador no PagSeguro
-    :param: token,
     '''
 
     @staticmethod
-    def _payment_factory(email, token, version):
+    def _payment_factory(version=2, **kwargs):
         if version == 2:
-            return PaymentV2(email, token)
+            return PaymentV2(**kwargs)
         else:
             raise NotImplementedError()
 
-    def __init__(self, email, token, version=2):
-        self._payment = self._payment_factory(email, token, version)
+    def __init__(self, **kwargs):
+        self._payment = self._payment_factory(**kwargs)
 
     def add_item(self, *args, **kwargs):
         '''
@@ -62,5 +70,5 @@ class Payment(object):
 
     @property
     def payment_url(self):
-        ''' '''
+        ''' URL para redirecionar o usuário para completar o pagamento '''
         return self._payment.payment_url()
